@@ -90,7 +90,7 @@ LATN_TO_HIRA = {
 
     'che': 'ちぇ', 'fa': 'ふぁ', 'vu': 'ゔ', 'fi': 'ふぃ', 'we': 'うぇ',
     'fo': 'ふぉ', 'fe': 'ふぇ', 'wi': 'うぃ', 'je': 'じぇ', 'fyu': 'ふゅ',
-    'vi': 'ゔぃ',
+    'vi': 'ゔぃ', 'va': 'ゔぁ',
 
     '-': 'ー', ':': 'ー',
     'n': 'ん', 'm': 'ん', "n'": 'ん', 'f': 'っ', 'j': 'っ',
